Internal plotting function for permutation variable importance plots
.plot_permutation_variable_importance(
x,
color_by,
facet_by,
facet_wrap_cols,
ggtheme,
discrete_palette,
x_label,
y_label,
legend_label,
plot_title,
plot_sub_title,
caption,
limit_n_features,
conf_int_style,
conf_int_alpha,
x_range,
x_breaks
)ggplot plot object.
(optional) Variables used to determine fill colour of plot
objects. The variables cannot overlap with those provided to the split_by
argument, but may overlap with other arguments. See details for available
variables.
(optional) Variables used to determine how and if facets of
each figure appear. In case the facet_wrap_cols argument is NULL, the
first variable is used to define columns, and the remaing variables are
used to define rows of facets. The variables cannot overlap with those
provided to the split_by argument, but may overlap with other arguments.
See details for available variables.
(optional) Number of columns to generate when facet wrapping. If NULL, a facet grid is produced instead.
(optional) ggplot theme to use for plotting.
(optional) Palette for colouring the plot elements
according to the groupings indicated by the color_by argument (if any).
familiar has a default palette. Other palettes are supported by
paletteer, grDevices::palette.pals() (requires R >= 4.0.0),
grDevices::hcl.pals() (requires R >= 3.6.0) and rainbow, heat.colors,
terrain.colors, topo.colors and cm.colors, which correspond to the
palettes of the same name in grDevices. You may also specify your own
palette by providing a vector of colour names listed by
grDevices::colors() or through hexadecimal RGB strings.
(optional) Label to provide to the x-axis. If NULL, no label is shown.
(optional) Label to provide to the y-axis. If NULL, no label is shown.
(optional) Label to provide to the legend. If NULL, the legend will not have a name.
(optional) Label to provide as figure title. If NULL, no title is shown.
(optional) Label to provide as figure subtitle. If NULL, no subtitle is shown.
(optional) Label to provide as figure caption. If NULL, no caption is shown.
(optional) The number of features that should be included in the plot. Only the most important features are shown. By default, the number of features is not limited.
(optional) Confidence interval style. See details for allowed styles.
(optional) Alpha value to determine transparency of confidence intervals or, alternatively, other plot elements with which the confidence interval overlaps. Only values between 0.0 (fully transparent) and 1.0 (fully opaque) are allowed.
(optional) Value range for the x-axis.
(optional) Break points on the x-axis of the plot.