dataObject-class: Data object

dataObject-classR Documentation

Data object

Description

The dataObject class is used to resolve the issue of keeping track of pre-processing status and data loading inside complex workflows, e.g. nested predict functions inside a calibration function.

Slots

data

NULL or data table containing the data. This is the data which will be read and used.

preprocessing_level

character indicating the level of pre-processing already conducted.

outcome_type

character, determines the outcome type.

outcome_info

Outcome information object, which contains additional information concerning the outcome, such as class levels.

feature_info

List of objects containing feature information, e.g., name, class levels, transformation, normalisation and clustering parameters. Optional.

data_column_info

Object containing column information.

data_id

Data identifier for dataset. Set using internal routines if the dataObject was created from a delayedDataObject

run_id

Run identifier for dataset. Set using internal routines if the dataObject was created from a delayedDataObject

validation

Identifies if validation or development samples were loaded. Set using internal routines if the dataObject was created from a delayedDataObject.

sample_seed

Seed used for creating a bootstrap of the data.


familiar documentation built on May 23, 2026, 1:07 a.m.