delayedDataObject-class: Data object with delayed loading

delayedDataObject-classR Documentation

Data object with delayed loading

Description

The delayed loading object provides an interface to the backend data. This data object is typically used within the evaluation pipeline to load data when needed.

Slots

data

NULL or data table containing the data. If present (not NULL), data is considered loaded. This should not happen – load_data_object auto- matically creates a dataObject from the delayedDataObject.

preprocessing_level

character indicating the level of pre-processing already conducted. "none" by default.

outcome_type

character, determines the outcome type.

outcome_info

Outcome information object, which contains additional information concerning the outcome, such as class levels.

feature_info

List of objects containing feature information, e.g., name, class levels, transformation, normalisation and clustering parameters. Optional.

data_column_info

Object containing column information.

data_id

integer. Defines the data_id of the dataset that should be loaded.

run_id

integer. Defines the run_id of the dataset that should be load. Together with data_id, run_id and validation allows for looking up the sample set. If run_id is left unset (NA_integer_), this will force the run_id to be set using the model, vimp_method or ensemble object. This is used during the evaluation process to load data specifically related to training, internal validation and external validation. The run-tables (which contain information about data partitioning) associated with these objects are used to look-up the run_id based on the data_id (that is always explicitly set). The perform_task method for familiarTaskEvaluate uses this aspect explicitly.

validation

logical. This determines which internal data set will be loaded. If TRUE, the validation data will be loaded, whereas FALSE loads the development data.

aggregate_on_load

logical. Determines whether data is aggregated after loading.

sample_set_on_load

NULL or vector of sample identifiers to be loaded. Overrides any sample_seed that may have been provided.


familiar documentation built on May 23, 2026, 1:07 a.m.