dot-plot_univariate_importance: Internal plotting function for univariate plots

.plot_univariate_importanceR Documentation

Internal plotting function for univariate plots

Description

Internal plotting function for univariate plots

Usage

.plot_univariate_importance(
  x,
  color_by,
  facet_by,
  facet_wrap_cols,
  ggtheme,
  show_cluster,
  discrete_palette,
  gradient_palette,
  x_label,
  y_label,
  legend_label,
  plot_title,
  plot_sub_title,
  caption,
  limit_n_features,
  x_range,
  x_breaks,
  significance_level_shown
)

Arguments

color_by

(optional) Variables used to determine fill colour of plot objects. The variables cannot overlap with those provided to the split_by argument, but may overlap with other arguments. See details for available variables.

facet_by

(optional) Variables used to determine how and if facets of each figure appear. In case the facet_wrap_cols argument is NULL, the first variable is used to define columns, and the remaing variables are used to define rows of facets. The variables cannot overlap with those provided to the split_by argument, but may overlap with other arguments. See details for available variables.

facet_wrap_cols

(optional) Number of columns to generate when facet wrapping. If NULL, a facet grid is produced instead.

ggtheme

(optional) ggplot theme to use for plotting.

show_cluster

(optional) Show which features were clustered together.

discrete_palette

(optional) Palette for colouring the plot elements according to the groupings indicated by the color_by argument (if any). familiar has a default palette. Other palettes are supported by paletteer, grDevices::palette.pals() (requires R >= 4.0.0), grDevices::hcl.pals() (requires R >= 3.6.0) and rainbow, heat.colors, terrain.colors, topo.colors and cm.colors, which correspond to the palettes of the same name in grDevices. You may also specify your own palette by providing a vector of colour names listed by grDevices::colors() or through hexadecimal RGB strings.

gradient_palette

(optional) Palette to use for filling the bars in case the color_by argument is not set. The bars are then coloured according to their importance. By default, no gradient is used, and the bars are not filled according to importance. Use NULL to fill the bars using the default palette in familiar. Other palettes are supported by the paletteer package, grDevices::palette.pals() (requires R >= 4.0.0), grDevices::hcl.pals() (requires R >= 3.6.0) and rainbow, heat.colors, terrain.colors, topo.colors and cm.colors, which correspond to the palettes of the same name in grDevices. You may also specify your own palette by providing a vector of colour names listed by grDevices::colors() or through hexadecimal RGB strings.

x_label

(optional) Label to provide to the x-axis. If NULL, no label is shown.

y_label

(optional) Label to provide to the y-axis. If NULL, no label is shown.

legend_label

(optional) Label to provide to the legend. If NULL, the legend will not have a name.

plot_title

(optional) Label to provide as figure title. If NULL, no title is shown.

plot_sub_title

(optional) Label to provide as figure subtitle. If NULL, no subtitle is shown.

caption

(optional) Label to provide as figure caption. If NULL, no caption is shown.

limit_n_features

(optional) The number of features that should be included in the plot. Only the most important features are shown. By default, the number of features is not limited.

x_range

(optional) Value range for the x-axis.

x_breaks

(optional) Break points on the x-axis of the plot.

significance_level_shown

Position(s) to draw vertical lines indicating a significance level, e.g. 0.05. Can be NULL to not draw anything.

Value

ggplot plot object.

See Also

  • plot_univariate_importance for the user interface.


familiar documentation built on May 23, 2026, 1:07 a.m.