| export_feature_expressions | R Documentation |
Extract and export feature expressions for the features in a familiarCollection.
export_feature_expressions(
object,
features = waiver(),
dir_path = NULL,
evaluation_time = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'familiarCollection'
export_feature_expressions(
object,
features = waiver(),
dir_path = NULL,
evaluation_time = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'ANY'
export_feature_expressions(
object,
features = waiver(),
dir_path = NULL,
evaluation_time = waiver(),
export_collection = FALSE,
...
)
object |
A |
features |
Features that should be exported. If |
dir_path |
Path to folder where extracted data should be saved. |
evaluation_time |
One or more time points that are used to create the
outcome columns in expression plots. If not provided explicitly, this
parameter is read from settings used at creation of the underlying
|
export_collection |
(optional) Exports the collection if TRUE. |
... |
Arguments passed on to
|
All parameters aside from object and dir_path are only used if object
is not a familiarCollection object, or a path to one.
Feature similarity data can be created from dataObject, or data.table objects.
For data.table, see as_data_object for additional arguments.
A data.table (if dir_path is not provided), or nothing, as all data
is exported to csv files.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.