| export_sample_similarity | R Documentation |
Extract and export mutual correlation between features in a familiarCollection.
export_sample_similarity(
object,
dir_path = NULL,
aggregate_results = TRUE,
sample_limit = waiver(),
sample_cluster_method = waiver(),
sample_linkage_method = waiver(),
export_dendrogram = FALSE,
export_collection = FALSE,
...
)
## S4 method for signature 'familiarCollection'
export_sample_similarity(
object,
dir_path = NULL,
aggregate_results = TRUE,
sample_limit = waiver(),
sample_cluster_method = waiver(),
sample_linkage_method = waiver(),
export_dendrogram = FALSE,
export_collection = FALSE,
...
)
## S4 method for signature 'ANY'
export_sample_similarity(
object,
dir_path = NULL,
aggregate_results = TRUE,
sample_limit = waiver(),
sample_cluster_method = waiver(),
sample_linkage_method = waiver(),
export_dendrogram = FALSE,
export_collection = FALSE,
...
)
object |
A |
dir_path |
Path to folder where extracted data should be saved. |
aggregate_results |
Flag that signifies whether results should be aggregated for export. |
sample_limit |
(optional) Set the upper limit of the number of samples that are used during evaluation steps. Cannot be fewer than 20. This setting can be specified per data element by providing a parameter
value in a named list with data elements, e.g.
This parameter can be set for the following data elements:
|
sample_cluster_method |
The method used to perform clustering based on
distance between samples. These are the same methods as for the
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
sample_linkage_method |
The method used for agglomerative clustering in
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
export_dendrogram |
Add dendrogram in the data element objects. |
export_collection |
(optional) Exports the collection if TRUE. |
... |
Arguments passed on to
|
All parameters aside from object and dir_path are only used if object
is not a familiarCollection object, or a path to one.
Sample similarity data can be created from dataObject, or data.table objects.
For data.table, see as_data_object for additional arguments.
A list containing a data.table (if dir_path is not provided), or
nothing, as all data is exported to csv files.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.