Learn R Programming

familiar (version 2.0.2)

extract_hyperparameters: Internal function to extract hyperparameters from models.

Description

Collects hyperparameters from models in a familiarEnsemble.

Usage

extract_hyperparameters(object, message_indent = 0L, verbose = FALSE, ...)

Value

A list of familiarDataElements with hyperparameters.

Arguments

object

A familiarEnsemble, which is an ensemble of one or more familiarModel objects, or a familiarDataElementPredictionTable object that contains prediction data.

message_indent

Number of indentation steps for messages shown during computation and extraction of various data elements.

verbose

Flag to indicate whether feedback should be provided on the computation and extraction of various data elements.

...

Unused arguments.