familiarNoveltyDetector-class: Novelty detector.

familiarNoveltyDetector-classR Documentation

Novelty detector.

Description

A familiarNoveltyDetector object is a self-contained model that can be applied to generate out-of-distribution predictions for instances in a dataset.

Details

Note that these objects do not contain any data concerning outcome, as this not relevant for (prospective) out-of-distribution detection.

Slots

name

Name of the familiarNoveltyDetector object.

model

The actual novelty detector trained using a specific algorithm, e.g. a isolation forest from the isotree package.

feature_info

List of objects containing feature information, e.g., name, class levels, transformation, normalisation and clustering parameters.

data_column_info

Data information object containing information regarding identifier column names.

hyperparameters

Set of hyperparameters used to train the detector.

hyperparameter_data

Information generated during hyperparameter optimisation. Currently not used.

calibration_model

Model used to convert raw output to statistical probability of being out-of-distribution. Currently not used.

learner

Learning algorithm used to create the novelty detector.

vimp_method

Method used to determine variable importance for the novelty detector.

vimp_table

Variable importance table or list of variable importance tables for the model.

vimp_aggregation_method

Method used for aggregating variable importance tables if more than one is present.)

vimp_rank_threshold

Threshold used for some variable importance aggregation methods.

required_features

The set of features required for complete reproduction, i.e. with imputation.

model_features

The set of features that is used to train the detector.

data_id

Internal identifier for the dataset used to train the detector.

run_id

Internal identifier for the specific subset of the dataset used used to train the detector.

run_table

Run table for the data used to train the detector. Used internally.

is_trimmed

Flag that indicates whether the detector, stored in the model slot, has been trimmed.

trimmed_function

List of functions whose output has been captured prior to trimming the model.

messages

List of warning and error messages generated during training.

project_id

Identifier of the project that generated the familiarNoveltyDetector object.

familiar_version

Version of the familiar package.

package

Name of package(s) required to executed the detector itself, e.g. isotree.

package_version

Version of the packages mentioned in the package attribute.


familiar documentation built on May 23, 2026, 1:07 a.m.