Learn R Programming

familiar (version 2.0.2)

get_vimp_method_names,familiarCollection-method: Get current variable importance method name labels

Description

Variable importance methods in familiarCollection objects can have custom names for export and plotting. This function retrieves the currently assigned names.

Usage

# S4 method for familiarCollection
get_vimp_method_names(x)

Value

An ordered array of variable importance method name labels.

Arguments

x

A familiarCollection object.

Details

Labels convert internal naming of variable importance methods to the requested label at export or when plotting. Labels can be changed using the set_vimp_method_names method.

See Also

  • familiarCollection for information concerning the familiarCollection class.

  • set_vimp_method_names for updating the name of variable importance methods and their ordering.