| get_vimp_method_names,familiarCollection-method | R Documentation |
Variable importance methods in familiarCollection objects can have custom names for export and plotting. This function retrieves the currently assigned names.
## S4 method for signature 'familiarCollection'
get_vimp_method_names(x)
x |
A familiarCollection object. |
Labels convert internal naming of variable importance methods to the
requested label at export or when plotting. Labels can be changed using the
set_vimp_method_names method.
An ordered array of variable importance method name labels.
familiarCollection for information concerning the familiarCollection class.
set_vimp_method_names for updating the name of variable importance methods and their ordering.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.