is.waive: Internal test to see if an object is a waiver

View source: R/Utilities.R

is.waiveR Documentation

Internal test to see if an object is a waiver

Description

This function tests if the object was created by the waiver function. This function is functionally identical to ggplot2:::is.waive().

Usage

is.waive(x)

Arguments

x

Object to be tested.

Value

TRUE for objects that are waivers, FALSE otherwise.


familiar documentation built on June 2, 2026, 1:08 a.m.