| plot_confusion_matrix | R Documentation |
This method creates confusion matrices based on data in a familiarCollection object.
plot_confusion_matrix(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
y_label = waiver(),
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
rotate_x_tick_labels = waiver(),
show_alpha = TRUE,
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'ANY'
plot_confusion_matrix(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
y_label = waiver(),
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
rotate_x_tick_labels = waiver(),
show_alpha = TRUE,
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'familiarCollection'
plot_confusion_matrix(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
y_label = waiver(),
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
rotate_x_tick_labels = waiver(),
show_alpha = TRUE,
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
object |
Additionally, some |
draw |
(optional) Draws the plot if TRUE. |
dir_path |
(optional) Path to the directory where created confusion
matrixes are saved to. Output is saved in the |
split_by |
(optional) Splitting variables. This refers to column names on which datasets are split. A separate figure is created for each split. See details for available variables. |
facet_by |
(optional) Variables used to determine how and if facets of
each figure appear. In case the |
facet_wrap_cols |
(optional) Number of columns to generate when facet wrapping. If NULL, a facet grid is produced instead. |
ggtheme |
(optional) |
discrete_palette |
(optional) Palette Palette for colouring the cells
of the confusion matrix. The colour depends on whether each cell of the
confusion matrix is on the diagonal (observed outcome matched expected
outcome) or not. |
x_label |
(optional) Label to provide to the x-axis. If NULL, no label is shown. |
y_label |
(optional) Label to provide to the y-axis. If NULL, no label is shown. |
legend_label |
(optional) Label to provide to the legend. If NULL, the legend will not have a name. |
plot_title |
(optional) Label to provide as figure title. If NULL, no title is shown. |
plot_sub_title |
(optional) Label to provide as figure subtitle. If NULL, no subtitle is shown. |
caption |
(optional) Label to provide as figure caption. If NULL, no caption is shown. |
rotate_x_tick_labels |
(optional) Rotate tick labels on the x-axis by
90 degrees. Defaults to |
show_alpha |
(optional) Interpreting confusion matrices is made easier
by setting the opacity of the cells.
|
width |
(optional) Width of the plot. A default value is derived from the number of facets. |
height |
(optional) Height of the plot. A default value is derived from the number of features and the number of facets. |
units |
(optional) Plot size unit. Either |
export_collection |
(optional) Exports the collection if TRUE. |
... |
Arguments passed on to
|
This function generates area under the ROC curve plots.
Available splitting variables are: vimp_method, learner and data_set.
By default, the data is split by vimp_method and learner, with facetting
by data_set.
Labelling methods such as set_vimp_method_names or set_data_set_names can
be applied to the familiarCollection object to update labels, and order
the output in the figure.
NULL or list of plot objects, if dir_path is NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.