| plot_permutation_variable_importance | R Documentation |
This function plots the data on permutation variable importance stored in a familiarCollection object.
plot_permutation_variable_importance(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
color_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
y_label = "feature",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
limit_n_features = waiver(),
x_range = NULL,
x_n_breaks = 5L,
x_breaks = NULL,
conf_int_style = c("point_line", "line", "bar_line", "none"),
conf_int_alpha = 0.2,
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'ANY'
plot_permutation_variable_importance(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
color_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
y_label = "feature",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
limit_n_features = waiver(),
x_range = NULL,
x_n_breaks = 5L,
x_breaks = NULL,
conf_int_style = c("point_line", "line", "bar_line", "none"),
conf_int_alpha = 0.2,
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'familiarCollection'
plot_permutation_variable_importance(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
color_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
y_label = "feature",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
limit_n_features = waiver(),
x_range = NULL,
x_n_breaks = 5L,
x_breaks = NULL,
conf_int_style = c("point_line", "line", "bar_line", "none"),
conf_int_alpha = 0.2,
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
object |
Additionally, some |
draw |
(optional) Draws the plot if TRUE. |
dir_path |
(optional) Path to the directory where created figures are
saved to. Output is saved in the |
split_by |
(optional) Splitting variables. This refers to column names on which datasets are split. A separate figure is created for each split. See details for available variables. |
color_by |
(optional) Variables used to determine fill colour of plot
objects. The variables cannot overlap with those provided to the |
facet_by |
(optional) Variables used to determine how and if facets of
each figure appear. In case the |
facet_wrap_cols |
(optional) Number of columns to generate when facet wrapping. If NULL, a facet grid is produced instead. |
ggtheme |
(optional) |
discrete_palette |
(optional) Palette for colouring the plot elements
according to the groupings indicated by the |
x_label |
(optional) Label to provide to the x-axis. If NULL, no label is shown. |
y_label |
(optional) Label to provide to the y-axis. If NULL, no label is shown. |
legend_label |
(optional) Label to provide to the legend. If NULL, the legend will not have a name. |
plot_title |
(optional) Label to provide as figure title. If NULL, no title is shown. |
plot_sub_title |
(optional) Label to provide as figure subtitle. If NULL, no subtitle is shown. |
caption |
(optional) Label to provide as figure caption. If NULL, no caption is shown. |
limit_n_features |
(optional) The number of features that should be included in the plot. Only the most important features are shown. By default, the number of features is not limited. |
x_range |
(optional) Value range for the x-axis. |
x_n_breaks |
(optional) Number of breaks to show on the x-axis of the
plot. |
x_breaks |
(optional) Break points on the x-axis of the plot. |
conf_int_style |
(optional) Confidence interval style. See details for allowed styles. |
conf_int_alpha |
(optional) Alpha value to determine transparency of confidence intervals or, alternatively, other plot elements with which the confidence interval overlaps. Only values between 0.0 (fully transparent) and 1.0 (fully opaque) are allowed. |
width |
(optional) Width of the plot. A default value is derived from the number of facets. |
height |
(optional) Height of the plot. A default value is derived from the number of features and the number of facets. |
units |
(optional) Plot size unit. Either |
export_collection |
(optional) Exports the collection if TRUE. |
... |
Arguments passed on to
|
This function generates a horizontal barplot that lists features by the estimated model improvement over that of a dataset where the respective feature is randomly permuted.
The following splitting variables are available for split_by, color_by
and facet_by:
vimp_method: variable importance methods.
learner: learners.
data_set: data sets.
metric: the model performance metrics.
evaluation_time: the evaluation times (survival outcomes only).
similarity_threshold: the similarity threshold used to identify groups
of features to permute simultaneously.
By default, the data is split by vimp_method, learner and metric,
faceted by data_set and evaluation_time, and coloured by
similarity_threshold.
Labelling methods such as set_vimp_method_names or set_feature_names can
be applied to the familiarCollection object to update labels, and order
the output in the figure.
Bootstrap confidence intervals (if present) can be shown using various
styles set by conf_int_style:
point_line (default): confidence intervals are shown as lines, on which
the point estimate is likewise shown.
line (default): confidence intervals are shown as lines, but the point
estimate is not shown.
bar_line: confidence intervals are shown as lines, with the point
estimate shown as a bar plot with the opacity of conf_int_alpha.
none: confidence intervals are not shown. The point estimate is shown as
a bar plot.
For metrics where lower values indicate better model performance, more negative permutation variable importance values indicate features that are more important. Because this may cause confusion, values obtained for these metrics are mirrored around 0.0 for plotting (but not any tabular data export).
NULL or list of plot objects, if dir_path is NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.