| plot_shap_force | R Documentation |
This method creates plots that show stacked SHAP force values obtained from the data stored in a familiarCollection object.
plot_shap_force(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
x_axis_by = NULL,
y_axis_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
x_label_shared = "column",
y_label = waiver(),
y_label_shared = "row",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
y_range = NULL,
y_n_breaks = 5L,
y_breaks = NULL,
highlight_feature = NULL,
sample_order = "prediction",
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'ANY'
plot_shap_force(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
x_axis_by = NULL,
y_axis_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
x_label_shared = "column",
y_label = waiver(),
y_label_shared = "row",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
y_range = NULL,
y_n_breaks = 5L,
y_breaks = NULL,
highlight_feature = NULL,
sample_order = "prediction",
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
## S4 method for signature 'familiarCollection'
plot_shap_force(
object,
draw = FALSE,
dir_path = NULL,
split_by = NULL,
x_axis_by = NULL,
y_axis_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
ggtheme = NULL,
discrete_palette = NULL,
x_label = waiver(),
x_label_shared = "column",
y_label = waiver(),
y_label_shared = "row",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
y_range = NULL,
y_n_breaks = 5L,
y_breaks = NULL,
highlight_feature = NULL,
sample_order = "prediction",
width = waiver(),
height = waiver(),
units = waiver(),
export_collection = FALSE,
...
)
object |
Additionally, some |
draw |
(optional) Draws the plot if TRUE. |
dir_path |
(optional) Path to the directory where created SHAP force
plots are saved to. Output is saved in the |
split_by |
(optional) Splitting variables. This refers to column names on which datasets are split. A separate figure is created for each split. See details for available variables. |
x_axis_by |
(optional) Variable plotted along the x-axis of a plot.
The variable cannot overlap with variables provided to the |
y_axis_by |
(optional) Variable plotted along the y-axis of a plot.
The variable cannot overlap with variables provided to the |
facet_by |
(optional) Variables used to determine how and if facets of
each figure appear. In case the |
facet_wrap_cols |
(optional) Number of columns to generate when facet wrapping. If NULL, a facet grid is produced instead. |
ggtheme |
(optional) |
discrete_palette |
(optional) Discrete palette used to colour the
elements of force plots. |
x_label |
(optional) Label to provide to the x-axis. If NULL, no label is shown. |
x_label_shared |
(optional) Sharing of x-axis labels between facets. One of three values:
|
y_label |
(optional) Label to provide to the y-axis. If NULL, no label is shown. |
y_label_shared |
(optional) Sharing of y-axis labels between facets. One of three values:
|
legend_label |
(optional) Label to provide to the legend. If NULL, the legend will not have a name. |
plot_title |
(optional) Label to provide as figure title. If NULL, no title is shown. |
plot_sub_title |
(optional) Label to provide as figure subtitle. If NULL, no subtitle is shown. |
caption |
(optional) Label to provide as figure caption. If NULL, no caption is shown. |
y_range |
(optional) Value range for the y-axis. |
y_n_breaks |
(optional) Number of breaks to show on the y-axis of the
plot. |
y_breaks |
(optional) Break points on the y-axis of the plot. |
highlight_feature |
(optional) Name of one or more features that should be highlighted in the force plot. |
sample_order |
(optional) Ordering of samples, one of:
|
width |
(optional) Width of the plot. A default value is derived from the number of facets. |
height |
(optional) Height of the plot. A default value is derived from the number of features and the number of facets. |
units |
(optional) Plot size unit. Either |
export_collection |
(optional) Exports the collection if TRUE. |
... |
Arguments passed on to
|
This function plots model performance based on empirical bootstraps, using various plot representations.
Available splitting variables are: vimp_method, learner, data_set,
evaluation_time (survival outcome only) and positive_class (categorical
outcomes). The default for is to facet by evaluation_time or
positive_class, and split by vimp_method, learner and data_set.
color_by is not used.
Labelling methods such as set_vimp_method_names or set_learner_names
can be applied to the familiarCollection object to update labels, and
order the output in the figure.
NULL or list of plot objects, if dir_path is NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.