| plot_univariate_importance | R Documentation |
This function plots the univariate analysis data stored in a familiarCollection object.
plot_univariate_importance(
object,
feature_cluster_method = waiver(),
feature_linkage_method = waiver(),
feature_cluster_cut_method = waiver(),
feature_similarity_threshold = waiver(),
draw = FALSE,
dir_path = NULL,
p_adjustment_method = waiver(),
split_by = NULL,
color_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
show_cluster = TRUE,
ggtheme = NULL,
discrete_palette = NULL,
gradient_palette = waiver(),
x_label = waiver(),
y_label = "feature",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
limit_n_features = waiver(),
x_range = NULL,
x_n_breaks = 5L,
x_breaks = NULL,
significance_level_shown = 0.05,
width = waiver(),
height = waiver(),
units = waiver(),
verbose = TRUE,
export_collection = FALSE,
...
)
## S4 method for signature 'ANY'
plot_univariate_importance(
object,
feature_cluster_method = waiver(),
feature_linkage_method = waiver(),
feature_cluster_cut_method = waiver(),
feature_similarity_threshold = waiver(),
draw = FALSE,
dir_path = NULL,
p_adjustment_method = waiver(),
split_by = NULL,
color_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
show_cluster = TRUE,
ggtheme = NULL,
discrete_palette = NULL,
gradient_palette = waiver(),
x_label = waiver(),
y_label = "feature",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
limit_n_features = waiver(),
x_range = NULL,
x_n_breaks = 5L,
x_breaks = NULL,
significance_level_shown = 0.05,
width = waiver(),
height = waiver(),
units = waiver(),
verbose = TRUE,
export_collection = FALSE,
...
)
## S4 method for signature 'familiarCollection'
plot_univariate_importance(
object,
feature_cluster_method = waiver(),
feature_linkage_method = waiver(),
feature_cluster_cut_method = waiver(),
feature_similarity_threshold = waiver(),
draw = FALSE,
dir_path = NULL,
p_adjustment_method = waiver(),
split_by = NULL,
color_by = NULL,
facet_by = NULL,
facet_wrap_cols = NULL,
show_cluster = TRUE,
ggtheme = NULL,
discrete_palette = NULL,
gradient_palette = waiver(),
x_label = waiver(),
y_label = "feature",
legend_label = waiver(),
plot_title = waiver(),
plot_sub_title = waiver(),
caption = NULL,
limit_n_features = waiver(),
x_range = NULL,
x_n_breaks = 5L,
x_breaks = NULL,
significance_level_shown = 0.05,
width = waiver(),
height = waiver(),
units = waiver(),
verbose = TRUE,
export_collection = FALSE,
...
)
object |
A |
feature_cluster_method |
The method used to perform clustering. These are
the same methods as for the
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
feature_linkage_method |
The method used for agglomerative clustering in
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
feature_cluster_cut_method |
The method used to divide features into
separate clusters. The available methods are the same as for the
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
feature_similarity_threshold |
The threshold level for pair-wise
similarity that is required to form feature clusters with the If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
draw |
(optional) Draws the plot if TRUE. |
dir_path |
(optional) Path to the directory where created figures are
saved to. Output is saved in the |
p_adjustment_method |
(optional) Indicates type of p-value that is
shown. One of |
split_by |
(optional) Splitting variables. This refers to column names on which datasets are split. A separate figure is created for each split. See details for available variables. |
color_by |
(optional) Variables used to determine fill colour of plot
objects. The variables cannot overlap with those provided to the |
facet_by |
(optional) Variables used to determine how and if facets of
each figure appear. In case the |
facet_wrap_cols |
(optional) Number of columns to generate when facet wrapping. If NULL, a facet grid is produced instead. |
show_cluster |
(optional) Show which features were clustered together. |
ggtheme |
(optional) |
discrete_palette |
(optional) Palette for colouring the plot elements
according to the groupings indicated by the |
gradient_palette |
(optional) Palette to use for filling the bars in
case the |
x_label |
(optional) Label to provide to the x-axis. If NULL, no label is shown. |
y_label |
(optional) Label to provide to the y-axis. If NULL, no label is shown. |
legend_label |
(optional) Label to provide to the legend. If NULL, the legend will not have a name. |
plot_title |
(optional) Label to provide as figure title. If NULL, no title is shown. |
plot_sub_title |
(optional) Label to provide as figure subtitle. If NULL, no subtitle is shown. |
caption |
(optional) Label to provide as figure caption. If NULL, no caption is shown. |
limit_n_features |
(optional) The number of features that should be included in the plot. Only the most important features are shown. By default, the number of features is not limited. |
x_range |
(optional) Value range for the x-axis. |
x_n_breaks |
(optional) Number of breaks to show on the x-axis of the
plot. |
x_breaks |
(optional) Break points on the x-axis of the plot. |
significance_level_shown |
Position(s) to draw vertical lines indicating a significance level, e.g. 0.05. Can be NULL to not draw anything. |
width |
(optional) Width of the plot. A default value is derived from the number of facets. |
height |
(optional) Height of the plot. A default value is derived from the number of features and the number of facets. |
units |
(optional) Plot size unit. Either |
verbose |
Flag to indicate whether feedback should be provided for the plotting. |
export_collection |
(optional) Exports the collection if TRUE. |
... |
Arguments passed on to
|
This function generates a horizontal barplot with the length of the bars corresponding to the 10-logarithm of the (multiple-testing corrected) p-value.
Features are assessed univariately using one-sample location t-tests after fitting a suitable regression model. The fitted model coefficient and the covariance matrix are then used to compute a p-value.
The following splitting variables are available for split_by, color_by
and facet_by:
vimp_method: variable importance methods
learner: learners
data_set: data sets
Unlike for plots of feature ranking in initial variable importance
computation and after modelling (as assessed by model-specific routines),
clusters of features are now found during creation of underlying
familiarData objects, instead of through consensus clustering. Hence,
clustering results may differ due to differences in the underlying
datasets.
Labelling methods such as set_vimp_method_names or set_feature_names can
be applied to the familiarCollection object to update labels, and order
the output in the figure.
NULL or list of plot objects, if dir_path is NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.