View source: R/PredictionTable.R
| as_prediction_table | R Documentation |
Creates a prediction table object from input data.
as_prediction_table(
x,
type,
y = waiver(),
batch_id = waiver(),
sample_id = waiver(),
series_id = waiver(),
repetition_id = waiver(),
time = waiver(),
class_levels = waiver(),
value_range = waiver(),
event_indicator = waiver(),
censoring_indicator = waiver(),
learner = waiver(),
vimp_method = waiver(),
model_object = NULL,
data = NULL
)
x |
Values predicted using a learner. For all but |
type |
The type of prediction table that should be created. The following types are available:
|
y |
Known outcome value corresponding to each entry in |
batch_id |
(optional) Array of batch or cohort identifiers. In familiar any row of data is organised by four identifiers:
|
sample_id |
(optional) Array of sample or subject identifiers. See
If unset, every row will be identified as a single sample. |
series_id |
(optional) Array of series identifiers, which distinguish
between measurements that are part of a series for a single sample. See
|
repetition_id |
(optional) Array of repetition identifiers, which
distinguishes between repeated measurements within a single series. See
|
time |
Time point at which the predicted values are generated e.g. the cumulative risks generated by random forest. This parameter is only relevant for |
class_levels |
(optional) Class levels for |
value_range |
Range of observed, not predicted, values. This parameter is only relevant for |
event_indicator |
(recommended) Indicator for events in |
censoring_indicator |
(recommended) Indicator for right-censoring in
|
learner |
The type of learner that generated the predictions. |
vimp_method |
The type of variable importance method for identifying the features included by the learner that generated the predictions. |
model_object |
A familiarModel or familiarEnsemble that can be used (and is used internally) for setting several of the other arguments of this function. |
data |
A familiar dataObject object that can be used (and is used internally) for setting many of the other arguments of this function. |
A prediction table object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.