| dataObject-class | R Documentation |
The dataObject class is used to resolve the issue of keeping track of pre-processing status and data loading inside complex workflows, e.g. nested predict functions inside a calibration function.
dataNULL or data table containing the data. This is the data which will be read and used.
preprocessing_levelcharacter indicating the level of pre-processing already conducted.
outcome_typecharacter, determines the outcome type.
outcome_infoOutcome information object, which contains additional information concerning the outcome, such as class levels.
feature_infoList of objects containing feature information, e.g., name, class levels, transformation, normalisation and clustering parameters. Optional.
data_column_infoObject containing column information.
data_idData identifier for dataset. Set using internal routines if the
dataObject was created from a delayedDataObject
run_idRun identifier for dataset. Set using internal routines if the
dataObject was created from a delayedDataObject
validationIdentifies if validation or development samples were loaded.
Set using internal routines if the dataObject was created from a
delayedDataObject.
sample_seedSeed used for creating a bootstrap of the data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.