| delayedDataObject-class | R Documentation |
The delayed loading object provides an interface to the backend data. This data object is typically used within the evaluation pipeline to load data when needed.
dataNULL or data table containing the data. If present (not NULL),
data is considered loaded. This should not happen – load_data_object auto-
matically creates a dataObject from the delayedDataObject.
preprocessing_levelcharacter indicating the level of pre-processing
already conducted. "none" by default.
outcome_typecharacter, determines the outcome type.
outcome_infoOutcome information object, which contains additional information concerning the outcome, such as class levels.
feature_infoList of objects containing feature information, e.g., name, class levels, transformation, normalisation and clustering parameters. Optional.
data_column_infoObject containing column information.
data_idinteger. Defines the data_id of the dataset that should be loaded.
run_idinteger. Defines the run_id of the dataset that should be load. Together with data_id, run_id and validation allows for looking up the sample set. If run_id is left unset (NA_integer_), this will force the run_id to be set using the model, vimp_method or ensemble object. This is used during the evaluation process to load data specifically related to training, internal validation and external validation. The run-tables (which contain information about data partitioning) associated with these objects are used to look-up the run_id based on the data_id (that is always explicitly set). The perform_task method for familiarTaskEvaluate uses this aspect explicitly.
validationlogical. This determines which internal data set will be loaded. If TRUE, the validation data will be loaded, whereas FALSE loads the development data.
aggregate_on_loadlogical. Determines whether data is aggregated after loading.
sample_set_on_loadNULL or vector of sample identifiers to be loaded.
Overrides any sample_seed that may have been provided.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.