| export_feature_similarity | R Documentation |
Extract and export mutual correlation between features in a familiarCollection.
export_feature_similarity(
object,
dir_path = NULL,
aggregate_results = TRUE,
features = waiver(),
feature_cluster_method = waiver(),
feature_linkage_method = waiver(),
feature_cluster_cut_method = waiver(),
feature_similarity_threshold = waiver(),
export_dendrogram = FALSE,
export_ordered_data = FALSE,
export_clustering = FALSE,
export_collection = FALSE,
...
)
## S4 method for signature 'familiarCollection'
export_feature_similarity(
object,
dir_path = NULL,
aggregate_results = TRUE,
features = waiver(),
feature_cluster_method = waiver(),
feature_linkage_method = waiver(),
feature_cluster_cut_method = waiver(),
feature_similarity_threshold = waiver(),
export_dendrogram = FALSE,
export_ordered_data = FALSE,
export_clustering = FALSE,
export_collection = FALSE,
...
)
## S4 method for signature 'ANY'
export_feature_similarity(
object,
dir_path = NULL,
aggregate_results = TRUE,
features = waiver(),
feature_cluster_method = waiver(),
feature_linkage_method = waiver(),
feature_cluster_cut_method = waiver(),
feature_similarity_threshold = waiver(),
export_dendrogram = FALSE,
export_ordered_data = FALSE,
export_clustering = FALSE,
export_collection = FALSE,
...
)
object |
A |
dir_path |
Path to folder where extracted data should be saved. |
aggregate_results |
Flag that signifies whether results should be aggregated for export. |
features |
Features that should be considered for extracting information from. Typically called in external workflows, e.g. for plotting. Internally, i.e. from summon_familiar, this variable is not used. |
feature_cluster_method |
The method used to perform clustering. These are
the same methods as for the
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
feature_linkage_method |
The method used for agglomerative clustering in
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
feature_cluster_cut_method |
The method used to divide features into
separate clusters. The available methods are the same as for the
If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
feature_similarity_threshold |
The threshold level for pair-wise
similarity that is required to form feature clusters with the If not provided explicitly, this parameter is read from settings used at
creation of the underlying |
export_dendrogram |
Add dendrogram in the data element objects. |
export_ordered_data |
Add feature label ordering to data in the data element objects. |
export_clustering |
Add clustering information to data. |
export_collection |
(optional) Exports the collection if TRUE. |
... |
Arguments passed on to
|
All parameters aside from object and dir_path are only used if object
is not a familiarCollection object, or a path to one.
Feature similarity data can be created from dataObject, or data.table objects.
For data.table, see as_data_object for additional arguments.
A list containing a data.table (if dir_path is not provided), or
nothing, as all data is exported to csv files.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.