Collects hyperparameters from models in a familiarEnsemble.
extract_hyperparameters(object, message_indent = 0L, verbose = FALSE, ...)A list of familiarDataElements with hyperparameters.
A familiarEnsemble, which is an ensemble of one or more
familiarModel objects, or a familiarDataElementPredictionTable object
that contains prediction data.
Number of indentation steps for messages shown during computation and extraction of various data elements.
Flag to indicate whether feedback should be provided on the computation and extraction of various data elements.
Unused arguments.