| familiarNoveltyDetector-class | R Documentation |
A familiarNoveltyDetector object is a self-contained model that can be applied to generate out-of-distribution predictions for instances in a dataset.
Note that these objects do not contain any data concerning outcome, as this not relevant for (prospective) out-of-distribution detection.
nameName of the familiarNoveltyDetector object.
modelThe actual novelty detector trained using a specific algorithm,
e.g. a isolation forest from the isotree package.
feature_infoList of objects containing feature information, e.g., name, class levels, transformation, normalisation and clustering parameters.
data_column_infoData information object containing information regarding identifier column names.
hyperparametersSet of hyperparameters used to train the detector.
hyperparameter_dataInformation generated during hyperparameter optimisation. Currently not used.
calibration_modelModel used to convert raw output to statistical probability of being out-of-distribution. Currently not used.
learnerLearning algorithm used to create the novelty detector.
vimp_methodMethod used to determine variable importance for the novelty detector.
vimp_tableVariable importance table or list of variable importance tables for the model.
vimp_aggregation_methodMethod used for aggregating variable importance tables if more than one is present.)
vimp_rank_thresholdThreshold used for some variable importance aggregation methods.
required_featuresThe set of features required for complete reproduction, i.e. with imputation.
model_featuresThe set of features that is used to train the detector.
data_idInternal identifier for the dataset used to train the detector.
run_idInternal identifier for the specific subset of the dataset used used to train the detector.
run_tableRun table for the data used to train the detector. Used internally.
is_trimmedFlag that indicates whether the detector, stored in the
model slot, has been trimmed.
trimmed_functionList of functions whose output has been captured prior to trimming the model.
messagesList of warning and error messages generated during training.
project_idIdentifier of the project that generated the familiarNoveltyDetector object.
familiar_versionVersion of the familiar package.
packageName of package(s) required to executed the detector itself,
e.g. isotree.
package_versionVersion of the packages mentioned in the package
attribute.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.