| update_object | R Documentation |
Provides backward compatibility for familiar objects exported to a file. This mitigates compatibility issues when working with files that become outdated as new versions of familiar are released, e.g. because slots have been removed.
Major version releases (e.g., versions 1.0.0, 2.0.0) introduce breaking changes which can result in objects that cannot be updated.
update_object(object, ...)
## S4 method for signature 'familiarModel'
update_object(object, ...)
## S4 method for signature 'familiarEnsemble'
update_object(object, ...)
## S4 method for signature 'familiarData'
update_object(object, ...)
## S4 method for signature 'familiarCollection'
update_object(object, ...)
## S4 method for signature 'vimpTable'
update_object(object, ...)
## S4 method for signature 'familiarNoveltyDetector'
update_object(object, ...)
## S4 method for signature 'featureInfo'
update_object(object, ...)
## S4 method for signature 'featureInfoParametersTransformationPowerTransform'
update_object(object, ...)
## S4 method for signature 'experimentData'
update_object(object, ...)
## S4 method for signature 'list'
update_object(object, ...)
## S4 method for signature 'ANY'
update_object(object, ...)
object |
A |
... |
Unused arguments. |
An up-to-date version of the respective S4 object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.